@@ -1,8 +1,9 @@
 #!/usr/bin/env bash
 
+set -e
+
 ./install_scripts_opt/install_nmz_mpfr.sh
-#./install_scripts_opt/install_nmz_flint_for_eantic.sh
 ./install_scripts_opt/install_nmz_flint.sh
 ./install_scripts_opt/install_nmz_arb.sh
-#./install_scripts_opt/install_nmz_antic.sh
-./install_scripts_opt/install_nmz_e-antic.sh
\ No newline at end of file
+./install_scripts_opt/install_nmz_antic.sh
+./install_scripts_opt/install_nmz_e-antic.sh
