@@ -145,7 +145,7 @@ void poly_div(vector<Integer>& q, vector<Integer>& r, const vector<Integer>& a,
     r = a;
     remove_zeros(r);
     size_t b_size = b.size();
-    int degdiff = r.size() - b_size;  // degree differenz
+    size_t degdiff = r.size() - b_size;  // degree differenz
     if (r.size() < b_size) {
         q = vector<Integer>();
     }
@@ -303,6 +303,10 @@ HilbertSeries::HilbertSeries() {
     initialize();
 }
 
+void HilbertSeries::set_to_one(){
+        num = vector<mpz_class>(1, 1);
+}
+
 // Constructor, creates num/denom, see class description for format
 HilbertSeries::HilbertSeries(const vector<num_t>& numerator, const vector<denom_t>& gen_degrees) {
     num = vector<mpz_class>(1, 0);
@@ -317,6 +321,20 @@ HilbertSeries::HilbertSeries(const vector<mpz_class>& numerator, const map<long,
     initialize();
 }
 
+HilbertSeries::HilbertSeries(const vector<mpz_class>& numerator, const vector<denom_t> given_denom) {
+
+    map<long, denom_t> denominator;
+    for(size_t i = 0; i < given_denom.size(); ++i){
+        if(denominator.find(given_denom[i]) == denominator.end())
+            denominator[given_denom[i]] = 1;
+        else
+            denominator[given_denom[i]]++;
+    }
+    num = numerator;
+    denom = denominator;
+    initialize();
+}
+
 /*
 // Constructor, string as created by to_string_rep
 HilbertSeries::HilbertSeries(const string& str) {
@@ -455,7 +473,7 @@ void HilbertSeries::simplify() const {
         poly = coeff_vector<mpz_class>(i);
         while (denom_i > 0) {
             poly_div(q, r, num, poly);
-            if (r.size() == 0) {  // numerator is divisable by poly
+            if (r.size() == 0) {  // numerator is divisible by poly
                 num = q;
                 denom_i--;
             }
@@ -489,7 +507,7 @@ void HilbertSeries::simplify() const {
         poly = cyclotomicPoly<mpz_class>(i);
         while (cyclo_i > 0) {
             poly_div(q, r, num, poly);
-            if (r.empty()) {  // numerator is divisable by poly
+            if (r.empty()) {  // numerator is divisible by poly
                 num = q;
                 cyclo_i--;
             }
@@ -620,7 +638,7 @@ void HilbertSeries::computeHilbertQuasiPolynomial() const {
     vector<long> denom_vec = to_vector(denom);
     if (nr_coeff_quasipol > (long)denom_vec.size()) {
         if (verbose)
-            verboseOutput() << "Number of coeff of quasipol too large. Reset to deault value." << endl;
+            verboseOutput() << "Number of coeff of quasipol too large. Reset to default value." << endl;
         nr_coeff_quasipol = -1;
     }
 
@@ -690,11 +708,11 @@ void HilbertSeries::computeHilbertQuasiPolynomial() const {
     for (j = 0; j < reduced_period; ++j) {
         INTERRUPT_COMPUTATION_BY_EXCEPTION
 
-        quasi_poly[j] = compute_polynomial(quasi_poly[j], dim);
+        quasi_poly[j] = compute_polynomial(quasi_poly[j], static_cast<int>(dim));
     }
 
     // substitute t by t/period:
-    // dividing by period^dim and multipling the coeff with powers of period
+    // dividing by period^dim and multiplying the coeff with powers of period
     mpz_class pp = 1;
     for (i = dim - 2; i >= 0; --i) {
         pp *= period;  // p^i   ok, it is p^(dim-1-i)
@@ -715,7 +733,7 @@ void HilbertSeries::computeHilbertQuasiPolynomial() const {
     g = libnormaliz::gcd(g, quasi_denom);
     quasi_denom /= g;
     QP.scalar_division(g);
-    // we use a normed shift, so that the cylcic shift % period always yields a non-negative integer
+    // we use a normed shift, so that the cyclic shift % period always yields a non-negative integer
     long normed_shift = -shift;
     while (normed_shift < 0)
         normed_shift += reduced_period;
@@ -849,6 +867,21 @@ void HilbertSeries::adjustShift() {
     }
 }
 
+ void HilbertSeries::increase_shift(const int d){
+     assert( d >= 0);
+     num.insert(num.begin(),d,0);
+     if(cyclo_num.size() > 0)
+        cyclo_num.insert(cyclo_num.begin(),0);
+ }
+
+ void HilbertSeries::multiply_denom(const int d){
+        assert(d > 0);
+        if(denom.find(d) != denom.end())
+            denom[d]+=1;
+        else
+            denom[d] = 1;
+ }
+
 /*
 // methods for textual transfer of a Hilbert Series
 string HilbertSeries::to_string_rep() const {
@@ -1111,7 +1144,7 @@ vector<Integer> compute_e_vector(vector<Integer> Q, int dim) {
     vector<Integer> E_Vector(dim, 0);
     // cout << "QQQ " << Q;
     // Q.resize(dim+1);
-    int bound = Q.size();
+    int bound = static_cast<int>(Q.size());
     if (bound > dim)
         bound = dim;
     for (i = 0; i < bound; i++) {
