@@ -64,11 +64,13 @@ namespace libnormaliz {
 
 bool verbose = false;
 bool constructor_verbose = true;
+bool polynomial_verbose = false;
 
 volatile sig_atomic_t nmz_interrupted = 0;
 const int default_thread_limit = 8;
 int thread_limit = default_thread_limit;
 bool parallelization_set = false;
+bool no_output_on_interrupt = false;
 
 // bool test_arithmetic_overflow = false;
 // long overflow_test_modulus = 15401;
@@ -88,6 +90,13 @@ bool int_max_value_primary_long_long_computed = false;
 
 vector<vector<vector<long> > > CollectedAutoms(default_thread_limit);  // for use in nmz_nauty.cpp
 
+vector<long> split_patches;
+vector<long> split_moduli;
+vector<long> split_residues;
+long split_res = -1;
+
+std::string global_project;
+
 #ifdef NMZ_EXTENDED_TESTS
 bool test_arith_overflow_full_cone = false;
 bool test_arith_overflow_dual_mode = false;
@@ -122,6 +131,12 @@ bool setVerboseDefault(bool v) {
     return old;
 }
 
+bool setPolynomialVerbose(bool onoff){
+    bool old = polynomial_verbose;
+    polynomial_verbose = onoff;
+    return old;
+}
+
 void suppressNextConstructorVerbose(){
         constructor_verbose = false;
 }
@@ -150,46 +165,52 @@ std::ostream& errorOutput() {
     return *error_ostream_ptr;
 }
 
-struct timeval TIME_global_begin, TIME_global_end;
+struct timeval TIME_global_begin, TIME_step_begin;
+double GlobalTimeBound = -1.0; // can be set in normaliz.cfg
+double GlobalPredictionTimeBound = -1.0;
+// -1.0 means: no time bound
+
+void StartTime(struct timeval& var_TIME_begin) {
+    gettimeofday(&var_TIME_begin, 0);
+}
+
+void StartTime(){
+        StartTime(TIME_step_begin);
+}
 
 void StartGlobalTime() {
-    gettimeofday(&TIME_global_begin, 0);
+    StartTime(TIME_global_begin);
+}
+
+double MeasureTime(const struct timeval var_TIME_begin) {
+    struct timeval time_end;
+    gettimeofday(&time_end, 0);
+    long seconds = time_end.tv_sec - var_TIME_begin.tv_sec;
+    long microseconds = time_end.tv_usec - var_TIME_begin.tv_usec;
+    double elapsed = seconds + microseconds * 1e-6;
+    return elapsed;
+}
+
+double TimeSinceStart(){
+    double elapsed = MeasureTime(TIME_global_begin);
+    return elapsed;
 }
 
 void MeasureGlobalTime(bool verbose) {
-    gettimeofday(&TIME_global_end, 0);
-    long seconds = TIME_global_end.tv_sec - TIME_global_begin.tv_sec;
-    long microseconds = TIME_global_end.tv_usec - TIME_global_begin.tv_usec;
-    double elapsed = seconds + microseconds * 1e-6;
+    double elapsed = TimeSinceStart();
     if (verbose)
         verboseOutput() << "Normaliz elapsed wall clock time: " << elapsed << " sec" << endl;
-    TIME_global_begin = TIME_global_end;
 }
 
-#ifdef NMZ_DEVELOP
-struct timeval TIME_begin, TIME_end;
-
-void StartTime() {
-    gettimeofday(&TIME_begin, 0);
-}
-
-void MeasureTime(bool verbose, const std::string& step) {
-    gettimeofday(&TIME_end, 0);
-    long seconds = TIME_end.tv_sec - TIME_begin.tv_sec;
-    long microseconds = TIME_end.tv_usec - TIME_begin.tv_usec;
-    double elapsed = seconds + microseconds * 1e-6;
+void PrintTime(const struct timeval var_TIME_begin, bool verbose, const std::string& step){
+    double elapsed = MeasureTime(var_TIME_begin);
     if (verbose)
         verboseOutput() << step << ": " << elapsed << " sec" << endl;
-    TIME_begin = TIME_end;
 }
-#else
-void StartTime() {
-    return;
+
+void MeasureTime(bool verbose, const std::string& step){
+    PrintTime(TIME_step_begin,verbose,step);
 }
-void MeasureTime(bool verbose, const std::string& step) {
-    return;
-}
-#endif
 
 unsigned int getVersion()
 {
