@@ -149,11 +149,16 @@ Matrix<Integer> readMatrix(const string project) {
     in >> nrows;
     in >> ncols;
 
-    if (nrows == 0 || ncols == 0)
-        throw BadInputException("readMatrix finds matrix empty");
+    Matrix<Integer> result(nrows, ncols);
+
+    if (nrows == 0 || ncols == 0){
+        if(verbose){
+            verboseOutput() << "Matrix in file " << project << " empty" << endl;
+        }
+        return result;
+    }
 
     int i, j;
-    Matrix<Integer> result(nrows, ncols);
 
     for (i = 0; i < nrows; ++i)
         for (j = 0; j < ncols; ++j) {
@@ -898,6 +903,9 @@ InputMap<Number> readNormalizInput(istream& in,
     set<NumParam::Param> num_par_already_set;
     bool we_have_a_polynomial = false;
     bool convert_equations = false;
+    size_t length_weight = 0;
+    bool monoid_read = false;
+    bool lattice_ideal_read = false;
 
     InputMap<Number> input_map;
 
@@ -1006,6 +1014,10 @@ InputMap<Number> readNormalizInput(istream& in,
                     options.activateNoMatricesOutput();
                     continue;
                 }
+                if (type_string == "NoOutputOnInterrupt") {
+                    options.activateNoOutputOnInterrupt();
+                    continue;
+                }
                 if (type_string == "NoSuppHypsOutput") {
                     options.activateNoSuppHypsOutput();
                     continue;
@@ -1060,17 +1072,48 @@ InputMap<Number> readNormalizInput(istream& in,
                     convert_equations = true;
                     continue;
                 }
+                if(type_string == "parallel_threads"){
+
+                    long nr_threads;
+                    in >> nr_threads;
+                    if(in.fail())
+                        throw BadInputException("Error after parallel_threads");
+                    set_thread_limit(nr_threads);
+                    continue;
+                }
 
                 input_type = to_type(type_string);
 
+                if(type_string == "monoid")
+                    monoid_read = true;
+
+                if(type_string == "lattice_ideal" || type_string == "toric_ideal")
+                    lattice_ideal_read = true;
+
+                if(type_string == "gb_weight"){
+                    if(!(monoid_read || lattice_ideal_read))
+                        throw BadInputException("gb_weight must follow monoid, lattice_ideal or toric_ideal");
+                    if(monoid_read){
+                        length_weight = input_map[Type::monoid].nr_of_rows();
+                    }
+                    else{
+                        length_weight = dim;
+                    }
+                }
+
                 if (dim_known)
                     nr_columns = dim + type_nr_columns_correction(input_type);
 
+                if(type_string == "gb_weight")
+                    nr_columns = length_weight;
+
                 if (type_is_vector(input_type)) {
                     nr_rows_or_columns = nr_rows = 1;
                     in >> std::ws;  // eat up any leading white spaces
                     c = in.peek();
                     if (c == 'u') {  // must be unit vector
+                        if(type_string == "gb_weight")
+                            throw BadInputException("gb_weight cannot be unit vector");
                         string vec_kind;
                         in >> vec_kind;
                         if (vec_kind != "unit_vector") {
@@ -1110,7 +1153,7 @@ InputMap<Number> readNormalizInput(istream& in,
                         }
 
                         vector<Number> sparse_vec;
-                        nr_columns = dim + type_nr_columns_correction(input_type);
+                        // nr_columns = dim + type_nr_columns_correction(input_type);
                         bool success = read_sparse_vector(in, sparse_vec, nr_columns);
                         if (!success) {
                             throw BadInputException("Error while reading " + type_string + " as a sparse vector!");
