@@ -42,6 +42,7 @@ using namespace std;
 #include "libnormaliz/input.h"
 #include "libnormaliz/options.h"
 #include "libnormaliz/chunk.h"
+#include "libnormaliz/collect_lat.h"
 
 using namespace libnormaliz;
 
@@ -58,7 +59,7 @@ void printHeader() {
 #endif
     cout << "                                                       \\...|" << endl;
     cout << "     (C) The Normaliz Team, University of Osnabrueck    \\..|" << endl;
-    cout << "                     January 2023                        \\.|" << endl;
+    cout << "                      June  2023                         \\.|" << endl;
     cout << "                                                          \\|" << endl;
     string optional_packages = package_string();
     if (optional_packages.size() > 0) {
@@ -143,7 +144,7 @@ int main(int argc, char* argv[]) {
     renf_class K("a^2 - 5", "a", "2.0 +/- 1.0");
     cout << "Constructed" << endl;
    renf_elem_class b(K, "a+1");
-   // std::cout << "number " << b << std::endl;
+   // cout << "number " << b << std::endl;
    cout << "Survived " << endl;*/
 
     // signal handler for interrupt
@@ -228,15 +229,26 @@ void compute_and_output(OptionsHandler& options,
             MyCone.compute(AddInputOptions);
         }
     } catch (const NotComputableException& e) {
-        std::cout << "Not all desired data could be computed." << endl;
-        std::cout << e.what() << endl;
-        std::cout << "Writing only available data." << endl;
+        cout << "Not all desired data could be computed." << endl;
+        cout << e.what() << endl;
+        cout << "Writing only available data." << endl;
     } catch (const InterruptException& e) {
-        std::cout << endl;
-        std::cout << "Computation was interrupted." << endl;
-        std::cout << e.what() << endl;
-        std::cout << "Writing only available data." << endl;
+        cout << endl;
+        cout << "Computation was interrupted." << endl;
+        cout << e.what() << endl;
+        if(no_output_on_interrupt){
+            cout << "No output on interrupt set" << endl;
+            exit(10);
+        }
+        cout << "Writing only available data." << endl;
     }
+
+    if(split_patches.size() >0){
+        cout << "No file <project>.out for split computation" << endl;
+        MeasureGlobalTime(verbose);
+        exit(0);
+    }
+
     Out.setCone(MyCone);
     Out.set_renf(number_field);
 
@@ -336,6 +348,13 @@ int process_data(OptionsHandler& options, const string& command_line) {
             exit(1);
         }
 
+        global_project = options.getProjectName();
+
+        if(options.isUseCollectLat()){
+            collect_lat();
+            exit(0);
+        }
+
         if (options.isUseChunk()) {
             chunk();
             exit(0);
@@ -346,6 +365,82 @@ int process_data(OptionsHandler& options, const string& command_line) {
             exit(0);
         }
 
+        if(options.isUseSplit()){
+            string name = options.getProjectName() + ".split.data";
+            ifstream split_control(name.c_str());
+            long nr_split_patches;
+            split_control >> nr_split_patches;
+            split_patches.resize(nr_split_patches);
+            split_moduli.resize(nr_split_patches);
+            long nr_splits_total = 1;
+            for(long i = 0; i < nr_split_patches; ++i){
+                    split_control >> split_patches[i] >> split_moduli[i];
+                    if(i == 0){
+                        if(split_patches[i] < 1)
+                            throw BadInputException("split patch must be > 0");
+                    }
+                    else{
+                        if(split_patches[i] <= split_patches[i-1])
+                            throw BadInputException("split patches must be increasing");
+                    }
+
+                    nr_splits_total *= split_moduli[i];
+            }
+
+            if(split_res >= nr_splits_total){
+                cerr << "Index of split too large, must be < " << nr_splits_total << endl;
+                exit(1);
+            }
+            long res = split_res;
+            split_residues.resize(nr_split_patches);
+            for(long i = 0; i < nr_split_patches; ++i){
+                split_residues[i] = res % split_moduli[i];
+                res /=  split_moduli[i];
+            }
+            if(verbose){
+                verboseOutput() << "split levels " << split_patches;
+                verboseOutput() << "split moduli " << split_moduli;
+                verboseOutput() << "split residues " << split_residues;
+            }
+        }
+
+        GlobalTimeBound = -1.0;
+        GlobalPredictionTimeBound = -1.0;
+        string name_time = "normaliz.time";
+        const char* file_time = name_time.c_str();
+        ifstream in_time;
+        in_time.open(file_time, ifstream::in);
+        if (in_time.is_open()) {
+            double test_input;
+            in_time >> test_input;
+            if(!in_time.fail()){
+                GlobalTimeBound = test_input;
+                if(verbose)
+                    verboseOutput() << "TIME BOUND " << GlobalTimeBound << endl;
+            }
+
+            in_time >> test_input;
+            if(!in_time.fail()){
+                GlobalPredictionTimeBound = test_input;
+                if(verbose)
+                    verboseOutput() << "TIME PREDICTION BOUND " << GlobalPredictionTimeBound << endl;
+            }
+            in_time.close();
+        }
+
+        /* string name_split = "normaliz.split";
+        const char* file_split = name_split.c_str();
+        ifstream in_split;
+        in_split.open(file_split, ifstream::in);
+        if (in_split.is_open()) {
+            in_split >> split_patch >> split_modulus >> split_res;
+            if(in_split.fail()){
+                verboseOutput() << "Split data incomplete" << endl;
+                exit(1);
+            }
+            in_split.close();
+        }*/
+
         string name_in = options.getProjectName() + ".in";
         const char* file_in = name_in.c_str();
         ifstream in;
@@ -434,6 +529,10 @@ int process_data(OptionsHandler& options, const string& command_line) {
         cerr << e.what() << endl;
         cerr << "FatalException caught... exiting." << endl;
         exit(2);
+    } catch (const TimeBoundException& e) {
+        cerr << e.what() << endl;
+        cerr << "Time bound exceeded ... exiting." << endl;
+        exit(6);
     } catch (const NmzCoCoAException& e) {
         cerr << e.what() << endl;
         cerr << "NmzCoCoAException caught... exiting." << endl;
